@@ -1,3 +1,5 @@
+from collections import defaultdict
+
 from sqlalchemy import Table, select, Connection, Select, text, TextClause
 
 from pancham.reporter import get_reporter
@@ -58,7 +60,6 @@ class DatabaseSearch:
         return value
 
 
-
 class CachingDatabaseSearch(DatabaseSearch):
     """
     Implements a caching mechanism for querying and retrieving data from a
@@ -122,7 +123,10 @@ class CachingDatabaseSearch(DatabaseSearch):
         search = self.cast_value(search_value, self.cast_search)
         reporter.report_debug(f"Finding id {search} - type {type(search)}")
 
-        return data.get(search, None)
+        if search in data:
+            return data[search]
+
+        return None
 
     def get_query(self, conn: Connection) -> Select|TextClause:
         """
@@ -136,7 +140,9 @@ class CachingDatabaseSearch(DatabaseSearch):
         :rtype: Select
         """
         data_table = Table(self.table_name, META, autoload_with=conn)
-        return select(data_table.c[self.search_col, self.value_col]).where(data_table.c[self.search_col].is_not(None))
+        return (select(data_table.c[self.search_col, self.value_col])
+                .where(data_table.c[self.search_col].is_not(None))
+                .where(data_table.c[self.value_col].is_not(None)))
 
     def __load_data(self) -> dict[str|int, str|int]:
         """
