@@ -21,11 +21,13 @@ def get_connection() -> Salesforce:
     url = os.environ.get('PANCHAM_SF_INSTANCE_URL', None)
     token = os.environ.get('PANCHAM_SF_TOKEN', None)
     domain = os.environ.get('PANCHAM_SF_DOMAIN', None)
+    api_version = os.environ.get('PANCHAM_SF_API_VERSION', '59.0')
 
     return Salesforce(
         username=username,
         password=password,
         instance_url=url,
         security_token=token,
-        domain=domain
+        domain=domain,
+        version=api_version
     )
\ No newline at end of file
