@@ -5,7 +5,7 @@ import pandas as pd
 from .validation import ContainsValidation, MatchingValidation, NotAllNullValidation, NotNullValidation, OneOfValidation
 from .validation_field import ValidationStep, ValidationInput
 from .configuration.database_match_field_parser import DatabaseMatchFieldParser
-from .configuration import DynamicFieldParser, DateTimeFieldParser, RemoveFieldParser, ToBoolFieldParser, SFLookupFieldParser, FillNanFieldParser, DatabaseFixedFieldParser, DatabaseMultiFieldSearchParser, StaticFieldParser, ToIntFieldParser, FieldParser, MatchFieldParser, SplitFieldParser, PartTextExtractorParser, ConcatFieldParser, TextFieldParser, EmailRegexMatchParser, RegexMatchFieldParser, NumberFormatFieldParser
+from .configuration import DynamicFieldParser, DateTimeFieldParser, RemoveFieldParser, RegexExtractFieldParser, ToBoolFieldParser, SFLookupFieldParser, FillNanFieldParser, DatabaseFixedFieldParser, DatabaseMultiFieldSearchParser, StaticFieldParser, ToIntFieldParser, FieldParser, MatchFieldParser, SplitFieldParser, PartTextExtractorParser, ConcatFieldParser, TextFieldParser, EmailRegexMatchParser, RegexMatchFieldParser, NumberFormatFieldParser
 from .configuration.explode_field_parser import ExplodeFieldParser
 from .configuration.deduplicate_field_parser import DeduplicateFieldParser
 from .data_frame_configuration import DataFrameConfiguration
@@ -18,7 +18,7 @@ from .file_loader import FileLoader, ExcelFileLoader, YamlFileLoader, CsvFileLoa
 from .output_configuration import OutputWriter, OutputConfiguration
 from .pancham_configuration import PanchamConfiguration, OrderedPanchamConfiguration
 from .reporter import Reporter, PrintReporter, get_reporter
-from .integration.salesforce_output import SalesforceBulkOutputConfiguration
+from .integration import SalesforceBulkOutputConfiguration, SalesforceCsvBulkOutputConfiguration, SalesforceRestUpdateOutputConfiguration
 from .integration.salesforce_query_loader import SalesforceQueryLoader
 
 DEFAULT_LOADERS = {
@@ -49,6 +49,7 @@ DEFAULT_FIELD_PARSERS = [
     RemoveFieldParser(),
     DeduplicateFieldParser(),
     RegexMatchFieldParser(),
+    RegexExtractFieldParser(),
     EmailRegexMatchParser(),
     SFLookupFieldParser(),
     FillNanFieldParser(),
@@ -57,7 +58,9 @@ DEFAULT_FIELD_PARSERS = [
 ]
 DEFAULT_OUTPUTS = [
     DatabaseOutput(),
-    SalesforceBulkOutputConfiguration()
+    SalesforceBulkOutputConfiguration(),
+    SalesforceCsvBulkOutputConfiguration(),
+    SalesforceRestUpdateOutputConfiguration()
 ]
 DEFAULT_VALIDATION_RULES = [
     NotNullValidation(),
